@@ -25,7 +25,9 @@ import sys
 import requests.exceptions
 
 from internetarchive.cli.cli_utils import (
-    prepare_args_dict,
+    FlattenListAction,
+    MetadataAction,
+    QueryStringAction,
     validate_identifier,
 )
 from internetarchive.utils import get_s3_xml_text
@@ -47,7 +49,7 @@ def setup(subparsers):
                         help="Identifier for the item from which files are to be deleted.")
     parser.add_argument("file",
                         type=str,
-                        nargs="+",
+                        nargs="*",
                         help="Specific file(s) to delete.")
 
     # Optional arguments
@@ -59,8 +61,8 @@ def setup(subparsers):
                         help="Delete all associated files including derivatives and the original.")
     parser.add_argument("-H", "--header",
                         nargs="+",
+                        action=QueryStringAction,
                         metavar="KEY:VALUE",
-                        action="append",
                         help="S3 HTTP headers to send with your request.")
     parser.add_argument("-a", "--all",
                         action="store_true",
@@ -74,14 +76,15 @@ def setup(subparsers):
                         help="Only delete files matching the given pattern.")
     parser.add_argument("-f", "--format",
                         type=str,
-                        nargs="*",
+                        nargs="+",
+                        action=FlattenListAction,
                         help="Only delete files matching the specified formats.")
     parser.add_argument("-R", "--retries",
                         type=int,
                         default=2,
                         help="Number of retries on S3 503 SlowDown error.")
     parser.add_argument("--no-backup",
-                        action="store_false",
+                        action="store_true",
                         help="Turn off archive.org backups. Clobbered files will not be saved.")
 
     parser.set_defaults(func=lambda args: main(args, parser))
@@ -153,8 +156,6 @@ def main(args: argparse.Namespace, parser: argparse.ArgumentParser):
     """
     Main entry point for 'ia delete'.
     """
-    args.header = prepare_args_dict(args.header, parser, arg_type="header")
-
     verbose = not args.quiet
     item = args.session.get_item(args.identifier)
     if not item.exists:
